pub struct BenchmarkInput {
pub sku: String,
pub quoted_price: f64,
pub supplier_id: Option<String>,
}Fields
sku: Stringquoted_price: f64supplier_id: Option<String>Trait Implementations
Sourceimpl Debug for BenchmarkInput
impl Debug for BenchmarkInput
Sourceimpl<'de> Deserialize<'de> for BenchmarkInput
impl<'de> Deserialize<'de> for BenchmarkInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchmarkInput
impl JsonSchema for BenchmarkInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BenchmarkInput
impl RefUnwindSafe for BenchmarkInput
impl Send for BenchmarkInput
impl Sync for BenchmarkInput
impl Unpin for BenchmarkInput
impl UnsafeUnpin for BenchmarkInput
impl UnwindSafe for BenchmarkInput