pub struct BudgetInput {
pub department: String,
pub category: String,
pub allocated: f64,
pub currency: Option<String>,
pub period: String,
}Fields
department: Stringcategory: Stringallocated: f64currency: Option<String>period: StringTrait Implementations
Sourceimpl Debug for BudgetInput
impl Debug for BudgetInput
Sourceimpl<'de> Deserialize<'de> for BudgetInput
impl<'de> Deserialize<'de> for BudgetInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BudgetInput
impl JsonSchema for BudgetInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BudgetInput
impl RefUnwindSafe for BudgetInput
impl Send for BudgetInput
impl Sync for BudgetInput
impl Unpin for BudgetInput
impl UnsafeUnpin for BudgetInput
impl UnwindSafe for BudgetInput