pub struct CarbonInput {
pub supplier_id: String,
pub weight_kg: f64,
pub distance_km: f64,
pub transport_mode: Option<String>,
}Fields
supplier_id: Stringweight_kg: f64distance_km: f64transport_mode: Option<String>Trait Implementations
Sourceimpl Debug for CarbonInput
impl Debug for CarbonInput
Sourceimpl<'de> Deserialize<'de> for CarbonInput
impl<'de> Deserialize<'de> for CarbonInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CarbonInput
impl JsonSchema for CarbonInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CarbonInput
impl RefUnwindSafe for CarbonInput
impl Send for CarbonInput
impl Sync for CarbonInput
impl Unpin for CarbonInput
impl UnsafeUnpin for CarbonInput
impl UnwindSafe for CarbonInput