pub struct CatalogSearchInput {
pub query: String,
pub supplier_id: Option<String>,
}Fields
query: Stringsupplier_id: Option<String>Trait Implementations
Sourceimpl Debug for CatalogSearchInput
impl Debug for CatalogSearchInput
Sourceimpl<'de> Deserialize<'de> for CatalogSearchInput
impl<'de> Deserialize<'de> for CatalogSearchInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CatalogSearchInput
impl JsonSchema for CatalogSearchInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CatalogSearchInput
impl RefUnwindSafe for CatalogSearchInput
impl Send for CatalogSearchInput
impl Sync for CatalogSearchInput
impl Unpin for CatalogSearchInput
impl UnsafeUnpin for CatalogSearchInput
impl UnwindSafe for CatalogSearchInput