pub struct ContractIdInput {
pub contract_id: String,
}Fields
contract_id: StringTrait Implementations
Sourceimpl Debug for ContractIdInput
impl Debug for ContractIdInput
Sourceimpl<'de> Deserialize<'de> for ContractIdInput
impl<'de> Deserialize<'de> for ContractIdInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContractIdInput
impl JsonSchema for ContractIdInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContractIdInput
impl RefUnwindSafe for ContractIdInput
impl Send for ContractIdInput
impl Sync for ContractIdInput
impl Unpin for ContractIdInput
impl UnsafeUnpin for ContractIdInput
impl UnwindSafe for ContractIdInput