pub struct ContractInput {
pub supplier_id: String,
pub title: String,
pub contract_type: String,
pub value: f64,
pub currency: Option<String>,
pub start_date: String,
pub end_date: String,
pub auto_renew: Option<bool>,
pub terms: Option<String>,
}Fields
supplier_id: Stringtitle: Stringcontract_type: Stringvalue: f64currency: Option<String>start_date: Stringend_date: Stringauto_renew: Option<bool>terms: Option<String>Trait Implementations
Sourceimpl Debug for ContractInput
impl Debug for ContractInput
Sourceimpl<'de> Deserialize<'de> for ContractInput
impl<'de> Deserialize<'de> for ContractInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContractInput
impl JsonSchema for ContractInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContractInput
impl RefUnwindSafe for ContractInput
impl Send for ContractInput
impl Sync for ContractInput
impl Unpin for ContractInput
impl UnsafeUnpin for ContractInput
impl UnwindSafe for ContractInput