pub struct DiversityInput {
pub supplier_id: String,
pub certifications: Vec<String>,
pub certified_by: Option<String>,
pub expiry_date: Option<String>,
}Fields
supplier_id: Stringcertifications: Vec<String>certified_by: Option<String>expiry_date: Option<String>Trait Implementations
Sourceimpl Debug for DiversityInput
impl Debug for DiversityInput
Sourceimpl<'de> Deserialize<'de> for DiversityInput
impl<'de> Deserialize<'de> for DiversityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiversityInput
impl JsonSchema for DiversityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiversityInput
impl RefUnwindSafe for DiversityInput
impl Send for DiversityInput
impl Sync for DiversityInput
impl Unpin for DiversityInput
impl UnsafeUnpin for DiversityInput
impl UnwindSafe for DiversityInput