pub struct DiversityReportInput {
pub certification: Option<String>,
}Fields
certification: Option<String>Trait Implementations
Sourceimpl Debug for DiversityReportInput
impl Debug for DiversityReportInput
Sourceimpl<'de> Deserialize<'de> for DiversityReportInput
impl<'de> Deserialize<'de> for DiversityReportInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiversityReportInput
impl JsonSchema for DiversityReportInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiversityReportInput
impl RefUnwindSafe for DiversityReportInput
impl Send for DiversityReportInput
impl Sync for DiversityReportInput
impl Unpin for DiversityReportInput
impl UnsafeUnpin for DiversityReportInput
impl UnwindSafe for DiversityReportInput