pub struct PoApproveInput {
pub po_id: String,
pub approved_by: String,
}Fields
po_id: Stringapproved_by: StringTrait Implementations
Sourceimpl Debug for PoApproveInput
impl Debug for PoApproveInput
Sourceimpl<'de> Deserialize<'de> for PoApproveInput
impl<'de> Deserialize<'de> for PoApproveInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PoApproveInput
impl JsonSchema for PoApproveInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PoApproveInput
impl RefUnwindSafe for PoApproveInput
impl Send for PoApproveInput
impl Sync for PoApproveInput
impl Unpin for PoApproveInput
impl UnsafeUnpin for PoApproveInput
impl UnwindSafe for PoApproveInput