pub struct PoCreateInput {
pub supplier_id: String,
pub lines: Vec<Value>,
pub currency: Option<String>,
pub delivery_date: Option<String>,
pub notes: Option<String>,
pub created_by: String,
}Fields
supplier_id: Stringlines: Vec<Value>currency: Option<String>delivery_date: Option<String>notes: Option<String>created_by: StringTrait Implementations
Sourceimpl Debug for PoCreateInput
impl Debug for PoCreateInput
Sourceimpl<'de> Deserialize<'de> for PoCreateInput
impl<'de> Deserialize<'de> for PoCreateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PoCreateInput
impl JsonSchema for PoCreateInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PoCreateInput
impl RefUnwindSafe for PoCreateInput
impl Send for PoCreateInput
impl Sync for PoCreateInput
impl Unpin for PoCreateInput
impl UnsafeUnpin for PoCreateInput
impl UnwindSafe for PoCreateInput