pub struct ReceiveInput {
pub po_id: String,
pub lines: Vec<Value>,
pub received_by: String,
pub notes: Option<String>,
}Fields
po_id: Stringlines: Vec<Value>received_by: Stringnotes: Option<String>Trait Implementations
Sourceimpl Debug for ReceiveInput
impl Debug for ReceiveInput
Sourceimpl<'de> Deserialize<'de> for ReceiveInput
impl<'de> Deserialize<'de> for ReceiveInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReceiveInput
impl JsonSchema for ReceiveInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReceiveInput
impl RefUnwindSafe for ReceiveInput
impl Send for ReceiveInput
impl Sync for ReceiveInput
impl Unpin for ReceiveInput
impl UnsafeUnpin for ReceiveInput
impl UnwindSafe for ReceiveInput