pub struct RfqResponseInput {
pub rfq_id: String,
pub supplier_id: String,
pub unit_prices: Vec<f64>,
pub lead_time_days: u32,
pub notes: Option<String>,
}Fields
rfq_id: Stringsupplier_id: Stringunit_prices: Vec<f64>lead_time_days: u32notes: Option<String>Trait Implementations
Sourceimpl Debug for RfqResponseInput
impl Debug for RfqResponseInput
Sourceimpl<'de> Deserialize<'de> for RfqResponseInput
impl<'de> Deserialize<'de> for RfqResponseInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RfqResponseInput
impl JsonSchema for RfqResponseInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RfqResponseInput
impl RefUnwindSafe for RfqResponseInput
impl Send for RfqResponseInput
impl Sync for RfqResponseInput
impl Unpin for RfqResponseInput
impl UnsafeUnpin for RfqResponseInput
impl UnwindSafe for RfqResponseInput