pub struct RiskScoreInput {
pub supplier_id: String,
}Fields
supplier_id: StringTrait Implementations
Sourceimpl Debug for RiskScoreInput
impl Debug for RiskScoreInput
Sourceimpl<'de> Deserialize<'de> for RiskScoreInput
impl<'de> Deserialize<'de> for RiskScoreInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RiskScoreInput
impl JsonSchema for RiskScoreInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RiskScoreInput
impl RefUnwindSafe for RiskScoreInput
impl Send for RiskScoreInput
impl Sync for RiskScoreInput
impl Unpin for RiskScoreInput
impl UnsafeUnpin for RiskScoreInput
impl UnwindSafe for RiskScoreInput