pub struct ScorecardInput {
pub supplier_id: String,
}Fields
supplier_id: StringTrait Implementations
Sourceimpl Debug for ScorecardInput
impl Debug for ScorecardInput
Sourceimpl<'de> Deserialize<'de> for ScorecardInput
impl<'de> Deserialize<'de> for ScorecardInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScorecardInput
impl JsonSchema for ScorecardInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScorecardInput
impl RefUnwindSafe for ScorecardInput
impl Send for ScorecardInput
impl Sync for ScorecardInput
impl Unpin for ScorecardInput
impl UnsafeUnpin for ScorecardInput
impl UnwindSafe for ScorecardInput