pub struct SpendInput {
pub start: Option<String>,
pub end: Option<String>,
pub supplier_id: Option<String>,
pub category: Option<String>,
}Fields
start: Option<String>end: Option<String>supplier_id: Option<String>category: Option<String>Trait Implementations
Sourceimpl Debug for SpendInput
impl Debug for SpendInput
Sourceimpl<'de> Deserialize<'de> for SpendInput
impl<'de> Deserialize<'de> for SpendInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SpendInput
impl JsonSchema for SpendInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SpendInput
impl RefUnwindSafe for SpendInput
impl Send for SpendInput
impl Sync for SpendInput
impl Unpin for SpendInput
impl UnsafeUnpin for SpendInput
impl UnwindSafe for SpendInput