pub struct ThreeWayMatchInput {
pub po_id: String,
pub invoice_number: String,
pub invoice_amount: f64,
}Fields
po_id: Stringinvoice_number: Stringinvoice_amount: f64Trait Implementations
Sourceimpl Debug for ThreeWayMatchInput
impl Debug for ThreeWayMatchInput
Sourceimpl<'de> Deserialize<'de> for ThreeWayMatchInput
impl<'de> Deserialize<'de> for ThreeWayMatchInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreeWayMatchInput
impl JsonSchema for ThreeWayMatchInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreeWayMatchInput
impl RefUnwindSafe for ThreeWayMatchInput
impl Send for ThreeWayMatchInput
impl Sync for ThreeWayMatchInput
impl Unpin for ThreeWayMatchInput
impl UnsafeUnpin for ThreeWayMatchInput
impl UnwindSafe for ThreeWayMatchInput